Struct dao_interface::migrate_msg::ProposalParams
source · pub struct ProposalParams {
pub close_proposal_on_execution_failure: bool,
pub pre_propose_info: PreProposeInfo,
}Expand description
The params we need to provide for migration msgs
Fields
close_proposal_on_execution_failure: boolpre_propose_info: PreProposeInfoTrait Implementations
sourceimpl Clone for ProposalParams
impl Clone for ProposalParams
sourcefn clone(&self) -> ProposalParams
fn clone(&self) -> ProposalParams
Returns a copy of the value. Read more
1.0.0 · sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moresourceimpl Debug for ProposalParams
impl Debug for ProposalParams
sourceimpl<'de> Deserialize<'de> for ProposalParams
impl<'de> Deserialize<'de> for ProposalParams
sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
sourceimpl JsonSchema for ProposalParams
impl JsonSchema for ProposalParams
sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
sourcefn json_schema(gen: &mut SchemaGenerator) -> Schema
fn json_schema(gen: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moresourceimpl PartialEq for ProposalParams
impl PartialEq for ProposalParams
sourcefn eq(&self, other: &ProposalParams) -> bool
fn eq(&self, other: &ProposalParams) -> bool
This method tests for
self and other values to be equal, and is used
by ==.sourceimpl Serialize for ProposalParams
impl Serialize for ProposalParams
impl StructuralPartialEq for ProposalParams