dao_
interface
2.5.0
Module token
Module Items
Structs
In crate dao_
interface
dao_interface
Module
token
Structs

Denom
Unit
DenomUnit represents a struct that describes a given denomination unit of the basic token.
Initial
Balance
Metadata
Metadata represents a struct that describes a basic token.
NewDenom
Metadata
NewToken
Info
Token
Factory
Callback